@@ -21,7 +21,6 @@ class KonohaTokenizer(Tokenizer):
     def __init__(
         self,
         tokenizer_name: str = "mecab",
-        with_postag: bool = False,
         user_dictionary_path: Optional[str] = None,
         system_dictionary_path: Optional[str] = None,
         model_path: Optional[str] = None,
@@ -32,7 +31,6 @@ class KonohaTokenizer(Tokenizer):
     ) -> None:
         self._tokenizer = WordTokenizer(
             tokenizer=tokenizer_name,
-            with_postag=with_postag,
             user_dictionary_path=user_dictionary_path,
             system_dictionary_path=system_dictionary_path,
             model_path=model_path,
@@ -50,14 +48,7 @@ class KonohaTokenizer(Tokenizer):
     @overrides
     def tokenize(self, text: str) -> List[Token]:
         konoha_tokens = self._tokenizer.tokenize(text)
-        tokens = [
-            Token(
-                text=token.surface,
-                lemma_=token.base_form,
-                pos_=token.postag,
-            )
-            for token in konoha_tokens
-        ]
+        tokens = [Token(text=token.surface, lemma_=token.base_form, pos_=token.postag) for token in konoha_tokens]
 
         for start_token in self._start_tokens:
             tokens.insert(0, Token(start_token, 0))
